:mod:`neuronvisio.controls` -- Gtk UI module
============================================

.. automodule:: neuronvisio.controls
   
:class:`Controls`
-----------------

.. autoclass:: Controls
   :members:

:class:`TimelineHelper`
-----------------------
   
.. autoclass:: TimelineHelper
   :members:

:class:`TimeLoop`
-----------------
   
.. autoclass:: TimeLoop
   :members:
